#!/bin/bash

# Assuming your CSV file is named users.csv
CSV_FILE="users.csv"

# Read the CSV file line by line into an array
mapfile -t lines < "$CSV_FILE"

# Iterate over each line
for line in "${lines[@]:1}"; do
    # Split the line into fields
    IFS=',' read -r username email password staff superuser <<< "$line"

    # Trim leading and trailing whitespace from each field
    username=$(echo "$username" | tr -d '[:space:]')
    email=$(echo "$email" | tr -d '[:space:]')
    password=$(echo "$password" | tr -d '[:space:]')
    staff=$(echo "$staff" | tr -d '[:space:]')
    superuser=$(echo "$superuser" | tr -d '[:space:]')

    # Build the command string based on staff and superuser values
    command="tutor local do createuser"
    if [ "$staff" -eq 1 ]; then
        command+=" --staff"
    fi
    if [ "$superuser" -eq 1 ]; then
        command+=" --superuser"
    fi
    command+=" $username $email -p $password"

    # Print debug information
    echo "Executing command: $command"

    # Execute the command and capture the output
    output=$(eval "$command" 2>&1)

    # Check the exit code
    exit_code=$?
    if [ $exit_code -eq 0 ]; then
        echo "Command finished successfully for $username"
    else
        echo "Error executing command for $username. Exit code: $exit_code"
        echo "Output: $output"
    fi

    # Sleep for a short duration to allow the previous command to finish
    sleep 2
done

# Exit the script
exit 0
